==> pympipool-0.5.1.tar.gz: pympipool-0.5.1/pympipool/executor/mpipool.py <==
import pickle
import sys

import cloudpickle

from pympipool.share.parallel import (
    initialize_zmq,
    parse_arguments,
    parse_socket_communication,
)


def main():
    from mpi4py import MPI

    MPI.pickle.__init__(
        cloudpickle.dumps,
        cloudpickle.loads,
        pickle.HIGHEST_PROTOCOL,
    )
    from mpi4py.futures import MPIPoolExecutor

    future_dict = {}
    argument_dict = parse_arguments(argument_lst=sys.argv)
    with MPIPoolExecutor(int(argument_dict["total_cores"])) as executor:
        if executor is not None:
            context, socket = initialize_zmq(
                host=argument_dict["host"], port=argument_dict["zmqport"]
            )
            while True:
                output = parse_socket_communication(
                    executor=executor,
                    input_dict=cloudpickle.loads(socket.recv()),
                    future_dict=future_dict,
                    cores_per_task=int(argument_dict["cores_per_task"]),
                )
                if "exit" in output.keys() and output["exit"]:
                    if "result" in output.keys():
                        socket.send(cloudpickle.dumps({"result": output["result"]}))
                    else:
                        socket.send(cloudpickle.dumps({"result": True}))
                    socket.close()
                    context.term()
                    break
                elif isinstance(output, dict):
                    socket.send(cloudpickle.dumps(output))


if __name__ == "__main__":
    main()

==> pympipool-0.5.2.tar.gz: pympipool-0.5.2/pympipool/executor/mpipool.py <==
import pickle
import sys

import cloudpickle

from pympipool.share.communication import (
    connect_to_socket_interface,
    send_result,
    close_connection,
    receive_instruction,
)
from pympipool.share.parallel import (
    parse_arguments,
    parse_socket_communication,
)


def main():
    from mpi4py import MPI

    MPI.pickle.__init__(
        cloudpickle.dumps,
        cloudpickle.loads,
        pickle.HIGHEST_PROTOCOL,
    )
    from mpi4py.futures import MPIPoolExecutor

    future_dict = {}
    argument_dict = parse_arguments(argument_lst=sys.argv)
    with MPIPoolExecutor(int(argument_dict["total_cores"])) as executor:
        if executor is not None:
            context, socket = connect_to_socket_interface(
                host=argument_dict["host"], port=argument_dict["zmqport"]
            )
            while True:
                output = parse_socket_communication(
                    executor=executor,
                    input_dict=receive_instruction(socket=socket),
                    future_dict=future_dict,
                    cores_per_task=int(argument_dict["cores_per_task"]),
                )
                if "exit" in output.keys() and output["exit"]:
                    if "result" in output.keys():
                        send_result(
                            socket=socket, result_dict={"result": output["result"]}
                        )
                    else:
                        send_result(socket=socket, result_dict={"result": True})
                    close_connection(socket=socket, context=context)
                    break
                elif isinstance(output, dict):
                    send_result(socket=socket, result_dict=output)


if __name__ == "__main__":
    main()
